<template>
  <a-card class="j-address-list-right-card-box" :bordered="false">
    <a-table
      ref="table"
      size="middle"
      :row-selection="rowSelection"
      bordered
      rowKey="id"
      :columns="columns"
      :dataSource="dataSource"
    >
    </a-table>
    <a-tabs type="card">
      <a-tab-pane key="1" tab="单位换算">
        <a-row type="flex" :gutter="5" justify="end">
        <a-col><a-button type="text" style="float:right" @click="batchDel(selectedDownRows)"><a-icon type="minus" style="color:rgba(28, 106, 235, 1)"></a-icon></a-button></a-col>
        <a-col><a-button type="text" style="float:right" @click="handleAdd(selectedRows)"><a-icon type="plus" style="color:rgba(28, 106, 235, 1)"></a-icon></a-button></a-col>
        <a-col><a-button type="text" style="float:right" @click="handleEdit(selectedDownRows)"><a-icon type="form" style="color:rgba(28, 106, 235, 1)"></a-icon></a-button></a-col>
      </a-row>
      </a-tab-pane>
    </a-tabs>
    <a-table
      ref="table"
      size="middle"
      :row-selection="rowDownSelection"
      bordered
      rowKey="id"
      :columns="downColumns"
      :dataSource="downDataSource"
    >
    </a-table>
    <mom-unit-conversion-modal ref="modalForm" ></mom-unit-conversion-modal>
  </a-card>
</template>

<script>
import { getAction } from '@/api/manage'
import MomUnitConversionModal from './MomUnitConversionModal'
import { deleteAction } from '@/api/manage'
import { JeecgListMixin } from '@/mixins/JeecgListMixin'

export default {
  name: 'MomUnitListRight',
  mixins: [JeecgListMixin],
  components: { MomUnitConversionModal },
  props: ['value'],
  data() {
    return {
      description: '计量单位信息',
      positionInfo: {},
      dataSource: null,
      unitCategoryId:"",
      downDataSource: null,
      selectedRowKeys:[],
      selectedRows:[],
      ids:"",
      selectedDownRowKeys:[],
      selectedDownRows:[],
      url: {
        deleteBatch: '/base/unit/onversion/deleteMomUnitOnversion',
        getListByUnitCategoryId:'/base/unit/getListByUnitCategoryId'
      },
      columns: [
        {
          title: '单位代码',
          width: '10%',
          align: 'center',
          dataIndex: 'num',
        },
        {
          title: '单位名称',
          width: '15%',
          align: 'center',
          dataIndex: 'name',
        },
        {
          title: '分类名称',
          width: '15%',
          align: 'center',
          dataIndex: 'categoryName',
        },
        {
          title: '创建人',
          width: '10%',
          align: 'center',
          dataIndex: 'createBy',
        },
        {
          title: '创建时间',
          width: '15%',
          align: 'center',
          dataIndex: 'createTime',
        },
        {
          title: '更新人',
          width: '10%',
          align: 'center',
          dataIndex: 'updateBy',
        },
        {
          title: '更新时间',
          width: '15%',
          align: 'center',
          dataIndex: 'updateTime',
        },
        {
          title: '备注',
          width: '10%',
          align: 'center',
          dataIndex: 'remark',
        },
      ],
      downColumns: [
        {
            title: '#',
            key: 'rowIndex',
            dataIndex: '',
            width: 40,
            align: 'center',
            customRender: (t, r, i) => parseInt(i) + 1
        },
        {
          title: '目标单位代码',
          width: '12%',
          align: 'center',
          dataIndex: 'targetUnitNum',
        },
        {
          title: '目标单位名称',
          width: '12%',
          align: 'center',
          dataIndex: 'targetUnitName',
        },
        {
          title: '换算比例',
          width: '15%',
          align: 'center',
          dataIndex: 'conversionRatio',
        },
        {
          title: '创建人',
          width: '10%',
          align: 'center',
          dataIndex: 'createBy',
        },
        {
          title: '创建时间',
          width: '15%',
          align: 'center',
          dataIndex: 'createTime',
        },
        {
          title: '更新人',
          width: '10%',
          align: 'center',
          dataIndex: 'updateBy',
        },
        {
          title: '更新时间',
          width: '15%',
          align: 'center',
          dataIndex: 'updateTime',
        },
        {
          title: '备注',
          width: '10%',
          align: 'center',
          dataIndex: 'remark',
        },
      ],
    }
  },
  computed: {
    rowSelection() {
      return {
        onChange: (selectedRowKeys, selectedRows) => {
          this.selectedRowKeys = selectedRowKeys
          this.selectedRows = selectedRows
          this.$emit('searchkeys', selectedRowKeys,selectedRows)
          this.ids=selectedRowKeys.join(",")
          this.getList()
        },
        getCheckboxProps: (record) => ({
          props: {
            disabled: record.name === 'Disabled User', // Column configuration not to be checked
            name: record.name,
          },
        }),
      }
    },
    rowDownSelection() {
      return {
        onChange: (selectedDownRowKeys, selectedDownRows) => {
          this.selectedDownRowKeys = selectedDownRowKeys
          this.selectedDownRows = selectedDownRows
        },
        getCheckboxProps: (record) => ({
          props: {
            disabled: record.name === 'Disabled User', // Column configuration not to be checked
            name: record.name,
          },
        }),
      }
    },
  },
  created() {
    this.loadData({ unitCategoryId: ''})
  },
  methods: {
    loadData({ unitCategoryId }) {
      let momUnit = {
        unitCategoryId,
      }
      
      getAction(this.url.getListByUnitCategoryId, momUnit)
        .then((res) => {
          if (res.success) {
            this.dataSource = res.result
        
          }
        })
        .finally(() => {
          this.loading = false
          this.cardLoading = false
        })
        
    },
    //根据选中的计量单位id调用查询单位换算列表接口
    getList(){
      getAction('/base/unit/onversion/getListByUnitId', {ids:this.ids})
        .then((res) => {
          if (res.success) {
            this.downDataSource = res.result
          }
        })
        .finally(() => {
          this.loading = false
          this.cardLoading = false
        })
    },
    //增加单位换算方法
    handleAdd(selectedRows){
      if (this.selectedRows.length <= 0) {
        this.$message.warning('请选择一条需要增加单位换算的计量单位！')
        return
      } else if (this.selectedRows.length > 1) {
        this.$message.warning('注意：只能选择一条需要增加单位换算的计量单位！')
        return
      } else {
        this.$refs.modalForm.add(selectedRows,{cb: this.getList})
      }
    },
    //修改数据（修改按钮触发）
    handleEdit(selectedDownRows) {
      if (this.selectedDownRows.length <= 0) {
        this.$message.warning('请选择一条需要修改的单位换算信息！')
        return
      } else if (this.selectedDownRows.length > 1) {
        this.$message.warning('注意：只能选择一条单位划算信息进行修改！')
        return
      } else {
        this.$refs.modalForm.edit(selectedDownRows, { cb: this.getList })
      }
    },
    //批量删除右侧数据（删除按钮触发）
    batchDel() {
      if (!this.url.deleteBatch) {
        this.$message.error('请设置url.deleteBatch属性!')
        return
      }
      if (this.selectedDownRowKeys.length <= 0) {
        this.$message.warning('请选择一条记录！')
        return
      } else {
        var ids = ''
        for (var a = 0; a < this.selectedDownRowKeys.length; a++) {
          ids += this.selectedDownRowKeys[a] + ','
        }
        var that = this
        this.$confirm({
          title: '确认删除',
          content: '是否删除选中数据?',
          onOk: function () {
            that.loading = true
            deleteAction(that.url.deleteBatch, { ids: ids })
              .then((res) => {
                if (res.success) {
                  that.$message.success(res.message)
                } else {
                  that.$message.warning(res.message)
                }
              })
              .finally(() => {
                that.loading = false
                //重新计算分页问题
                that.reCalculatePage(that.selectedDownRowKeys.length)
                that.onClearSelected()
                this.getList()
                that.loadTree()
              })
          },
        })
      }
    },
    //重新计算分页
    reCalculatePage(count) {
      //总数量-count
      let total = this.ipagination.total - count
      //获取删除后的分页数
      let currentIndex = Math.ceil(total / this.ipagination.pageSize)
      //删除后的分页数<所在当前页
      if (currentIndex < this.ipagination.current) {
        this.ipagination.current = currentIndex
      }
      console.log('currentIndex', currentIndex)
    },
    //清除单位换算选中项
    onClearSelected() {
      this.selectedDownRowKeys = []
      this.selectedDownRows = []
    },
    
  },
}
</script>
<style>
.j-address-list-right-card-box .ant-table-placeholder {
  min-height: 46px;
}
</style>
<style scoped>
.j-address-list-right-card-box {
  height: 100%;
  min-height: 300px;
}
</style>